@@ -2,6 +2,7 @@ import time
 from typing import overload, Callable, Optional
 from dataclasses import dataclass, field
 
+from fred.worker.settings import FRD_WORKER_DEFAULT_BROADCAST
 from fred.future.impl import Future  # Should we make this import lazy?
 from fred.utils.dateops import datetime_utcnow
 from fred.settings import (
@@ -139,14 +140,14 @@ class HandlerInterface:
         return json.loads(metadata_serialized)
 
     @overload
-    def run(self, event: dict, as_future: bool = True, future_id: Optional[str] = None) -> Future[dict]:
+    def run(self, event: dict, as_future: bool = True, broadcast: Optional[bool] = None, future_id: Optional[str] = None) -> Future[dict]:
         ...
 
     @overload
-    def run(self, event: dict, as_future: bool = False, future_id: Optional[str] = None) -> dict:
+    def run(self, event: dict, as_future: bool = False, broadcast: Optional[bool] = None, future_id: Optional[str] = None) -> dict:
         ...
 
-    def run(self, event: dict, as_future: bool = False, future_id: Optional[str] = None) -> dict | Future[dict]:
+    def run(self, event: dict, as_future: bool = False, broadcast: Optional[bool] = None, future_id: Optional[str] = None) -> dict | Future[dict]:
         """Process an incoming event and return a structured response.
         The event is expected to be a dictionary with at least an 'id' and 'input' keys.
         The 'input' key should contain the payload to be processed.
@@ -158,7 +159,11 @@ class HandlerInterface:
                 If requested as a Future, returns a Future that will resolve to the response dictionary.
         """
         if as_future:
-            return Future(function=lambda: self.run(event=event, as_future=False), future_id=future_id)
+            return Future(
+                future_id=future_id,
+                function=lambda: self.run(event=event, as_future=False),
+                broadcast=FRD_WORKER_DEFAULT_BROADCAST if broadcast is None else broadcast,
+            )
         # Extract payload and event ID
         payload = event.get("input", {})
         job_event_identifier = event.get("id")
